@@ -41,7 +41,7 @@ appropriate action can be taken.
 use 5.00503;
 use strict;
 
-$Mail::DeliveryStatus::VERSION = '1.511';
+$Mail::DeliveryStatus::BounceParser::VERSION = '1.512';
 
 use MIME::Parser;
 use Mail::DeliveryStatus::Report;
@@ -165,7 +165,7 @@ sub parse {
     last if !$first_part || $first_part->effective_type ne 'text/plain';
     my $string = $first_part->as_string;
     last if length($string) > 3000;
-    last if $string !~ /auto.*repl|vacation|(out|away|on holiday).*office/is;
+    last if $string !~ /auto.{0,20}reply|vacation|(out|away|on holiday).*office/i;
     $self->log("looks like a vacation autoreply, ignoring.");
     $self->{type} = "vacation autoreply";
     $self->{is_bounce} = 0;
@@ -380,7 +380,7 @@ sub parse {
       );
 
       $report->replace(
-        smtp_code => ($report->get("diagnostic-code") =~ /((\d{3})\s|\s(\d{3}))/)[0]
+        smtp_code => ($report->get("diagnostic-code") =~ /((\d{3})\s|\s(\d{3})(?!\.))/)[0]
       );
 
       if (not $report->get("host")) {
@@ -463,7 +463,7 @@ sub parse {
     # they usually say "returned message" somewhere, and we can split on that,
     # above and below.
 
-    if ($message->bodyhandle->as_string =~ $Returned_Message_Below) {
+    if (($message->bodyhandle->as_string||'') =~ $Returned_Message_Below) {
       my ($stuff_before, $stuff_splitted, $stuff_after) =
         split $Returned_Message_Below, $message->bodyhandle->as_string, 3;
       # $self->log("splitting on \"$stuff_splitted\", " . length($stuff_before)
@@ -916,7 +916,8 @@ sub p_ms {
   #
 
   # $self->log("p_ms: didn't match domain") and
-  return unless $message->head->get("from") =~ /MAILER-DAEMON\@($domain)\b/i;
+  return
+    unless ($message->head->get("from")||'') =~ /MAILER-DAEMON\@($domain)\b/i;
 
   $domain = $1;
 
